==> nodeinfo-0.3.2.tar.gz: nodeinfo-go/nodeinfo.go <==
package nodeinfo

import (
	"fmt"
	"net/http"
)

// Node metadata about a server running in the federation
type Node struct {
	Version           string                 `json:"version"`
	Instance          Instance               `json:"instance"`
	Software          Software               `json:"software"`
	Protocols         []string               `json:"protocols"`
	Services          Services               `json:"services"`
	OpenRegistrations bool                   `json:"openRegistrations"`
	Usage             Usage                  `json:"usage"`
	Metadata          map[string]interface{} `json:"metadata"`
}

// Instance contain metadata specific to the instance
type Instance struct {
	Name        string `json:"name,omitempty"`
	Description string `json:"description,omitempty"`
}

// Software is about node software
type Software struct {
	Name       string `json:"name"`
	Version    string `json:"version"`
	Repository string `json:"repository"`
	Homepage   string `json:"homepage"`
}

// Services tell about third party sites the node can connect to or interact with
type Services struct {
	Inbound  []string `json:"inbound"`
	Outbound []string `json:"outbound"`
}

// Usage are usage statistics for the node
type Usage struct {
	Users         UsersUsage `json:"users"`
	LocalPosts    int64      `json:"localPosts,omitempty"`
	LocalComments int64      `json:"localComments,omitempty"`
}

// UsersUsage are statistics about the users of the node
type UsersUsage struct {
	Total          int64 `json:"total,omitempty"`
	ActiveHalfyear int64 `json:"activeHalfyear,omitempty"`
	ActiveMonth    int64 `json:"activeMonth,omitempty"`
	ActiveWeek     int64 `json:"activeWeek",omitempty`
}

// QueryNode fetch node info based on domain, can return more than one node if e.g. matrix and mastodon share the same domain name
func QueryNode(domain string, opts ...QueryNodeOption) ([]*Node, error) {
	f, err := NewFetcher(opts...)
	if err != nil {
		return nil, fmt.Errorf("could not create fetcher: %w", err)
	}
	return f.QueryNode(domain)
}

// QueryNodeOption are functions to be used as options for QueryNode
type QueryNodeOption func(f *fetcher) error

// QueryOptionClient return an option for QueryNode that can set an specific http client
func QueryOptionClient(c *http.Client) QueryNodeOption {
	return func(f *fetcher) error {
		f.client = c
		return nil
	}
}

// QueryOptionNoNodeinfo do not discovery based on the nodeinfo2 specification
func QueryOptionNoNodeinfo() QueryNodeOption {
	return func(f *fetcher) error {
		f.nodeinfo = false
		return nil
	}
}

// QueryOptionNoMatrix do not discovery based on the matrix specification
func QueryOptionNoMatrix() QueryNodeOption {
	return func(f *fetcher) error {
		f.matrix = false
		return nil
	}
}

==> nodeinfo-1.0.0.tar.gz: nodeinfo-go/nodeinfo.go <==
package nodeinfo

import (
	"fmt"
	"net/http"
)

// Node metadata about a server running in the federation
type Node struct {
	Version           string                 `json:"version"`
	Instance          Instance               `json:"instance"`
	Software          Software               `json:"software"`
	Protocols         []string               `json:"protocols"`
	Services          Services               `json:"services"`
	OpenRegistrations bool                   `json:"openRegistrations"`
	Usage             Usage                  `json:"usage"`
	Metadata          map[string]interface{} `json:"metadata"`
}

// Instance contain metadata specific to the instance
type Instance struct {
	Name        string `json:"name,omitempty"`
	Description string `json:"description,omitempty"`
}

// Software is about node software
type Software struct {
	Name       string `json:"name"`
	Version    string `json:"version"`
	Repository string `json:"repository"`
	Homepage   string `json:"homepage"`
}

// Services tell about third party sites the node can connect to or interact with
type Services struct {
	Inbound  []string `json:"inbound"`
	Outbound []string `json:"outbound"`
}

// Usage are usage statistics for the node
type Usage struct {
	Users         UsersUsage `json:"users"`
	LocalPosts    int64      `json:"localPosts,omitempty"`
	LocalComments int64      `json:"localComments,omitempty"`
}

// UsersUsage are statistics about the users of the node
type UsersUsage struct {
	Total          int64 `json:"total,omitempty"`
	ActiveHalfyear int64 `json:"activeHalfyear,omitempty"`
	ActiveMonth    int64 `json:"activeMonth,omitempty"`
	ActiveWeek     int64 `json:"activeWeek,omitempty"`
}

// QueryNode fetch node info based on domain, can return more than one node if e.g. matrix and mastodon share the same domain name
func QueryNode(domain string, opts ...QueryNodeOption) ([]*Node, error) {
	f, err := NewFetcher(opts...)
	if err != nil {
		return nil, fmt.Errorf("could not create fetcher: %w", err)
	}
	return f.QueryNode(domain)
}

// QueryNodeOption are functions to be used as options for QueryNode
type QueryNodeOption func(f *fetcher) error

// QueryOptionClient return an option for QueryNode that can set an specific http client
func QueryOptionClient(c *http.Client) QueryNodeOption {
	return func(f *fetcher) error {
		f.client = c
		return nil
	}
}

// QueryOptionNoNodeinfo do not discovery based on the nodeinfo2 specification
func QueryOptionNoNodeinfo() QueryNodeOption {
	return func(f *fetcher) error {
		f.nodeinfo = false
		return nil
	}
}

// QueryOptionNoMatrix do not discovery based on the matrix specification
func QueryOptionNoMatrix() QueryNodeOption {
	return func(f *fetcher) error {
		f.matrix = false
		return nil
	}
}
